# Is Python3 available?
%global with_python3 1

%global upname joblib

%global common_description						\
Joblib is a set of tools to provide lightweight pipelining in Python.	\
In particular, joblib offers:						\
 * transparent disk-caching of the output values and lazy		\
   re-evaluation (memorize pattern)					\
 * easy simple parallel computing					\
 * logging and tracing of the execution

Name: python-%{upname}
Version: 0.9.0b4
Release: %mkrel 2
Summary: Lightweight pipelining: using Python functions as pipeline jobs
License: BSD
Group:   Development/Python

URL: http://pythonhosted.org/joblib
Source0: https://pypi.python.org/packages/source/j/joblib/joblib-%{version}.tar.gz
BuildArch: noarch
BuildRequires: python-numpy
BuildRequires: python-nose
BuildRequires: python-devel
# Required by doctests
BuildRequires: python-setuptools
BuildRequires: python-sphinx
Requires: python-numpy

%description
%{common_description}

%if 0%{?with_python3}
%package -n python3-joblib
Summary: Lightweight pipelining: using Python functions as pipeline jobs

BuildRequires: python3-numpy
BuildRequires: python3-nose
BuildRequires: python3-devel
# Required by doctests
BuildRequires: python3-setuptools
BuildRequires: python3-sphinx
BuildRequires: python3-sphinx_rtd_theme
Requires: python3-numpy

%description -n python3-joblib
%{common_description}
%endif # 0%{?with_python3}

%prep
%setup -qn %{upname}-%{version}
rm -rf %{upname}.egg-info

%if 0%{?with_python3}
rm -rf %{py3dir}
cp -a . %{py3dir}
find %{py3dir} -name '*.py' | xargs sed -i '1s|^#!python|#!%{__python3}|'

# Fix failing testsuite, executable files are skipped
# chmod +x %{py3dir}/doc/sphinxext/autosummary_generate.py
%endif # 0%{?with_python3}

find -name '*.py' | xargs sed -i '1s|^#!python|#!%{__python}|'

%build
%{__python} setup.py build
%{__python} setup.py build_sphinx
rm -f build/sphinx/html/.buildinfo

%if 0%{?with_python3}
pushd %{py3dir}
%{__python3} setup.py build
# The doc system is not compatible with python3
popd
%endif # 0%{?with_python3}

%install
%{__python} setup.py install --skip-build --root %{buildroot}

%if 0%{?with_python3}
pushd %{py3dir}
%{__python3} setup.py install --skip-build --root %{buildroot}
popd
%endif # 0%{?with_python3}

%check
pushd %{buildroot}/%{python_sitelib}
nosetests-%{python_version} -v
popd

%if 0%{?with_python3}
# Cancelling due to failing tests.
%if 0
pushd %{buildroot}/%{python3_sitelib}
nosetests-%{python3_version} -v
popd
%endif
%endif # 0%{?with_python3}

%files
%doc build/sphinx/html README*
%{python_sitelib}/%{upname}
%{python_sitelib}/%{upname}-%{version}-py%{python_version}.egg-info

%if 0%{?with_python3}
%files -n python3-%{upname}
%doc build/sphinx/html README*
%{python3_sitelib}/%{upname}
%{python3_sitelib}/%{upname}-%{version}-py%{python3_version}.egg-info
%endif # 0%{?with_python3}


%changelog
* Sat Feb 20 2016 umeabot <umeabot> 0.9.0b4-2.mga6
+ Revision: 971187
- Mageia 6 Mass Rebuild

* Sun Oct 11 2015 shlomif <shlomif> 0.9.0b4-1.mga6
+ Revision: 889661
- New version 0.9.0 + Rebuild for Python3 3.5.x

  + tv <tv>
    - rebuild for python 3.5

* Mon Dec 22 2014 joequant <joequant> 0.8.3-1.mga5
+ Revision: 804763
- fix group
- imported package python-joblib

